==> lhcsmapi-1.4.58.tar.gz: lhcsmapi-1.4.58/lhcsmapi/analysis/R600ACircuitQuery.py <==
from typing import List

import pandas as pd

import lhcsmapi
from lhcsmapi.Time import Time
from lhcsmapi.analysis.CircuitQuery import CircuitQuery
from lhcsmapi.analysis.dfb.DfbQuery import DfbQuery
from lhcsmapi.analysis.ee.EeQuery import EeQuery
from lhcsmapi.analysis.pc.PcQuery import PcQuery
from lhcsmapi.analysis.pic.PicQuery import PicQuery
from lhcsmapi.analysis.qds.QdsQuery import QdsQuery
from lhcsmapi.reference.Reference import Reference


class R600ACircuitQuery(PicQuery, PcQuery, EeQuery, QdsQuery, DfbQuery, CircuitQuery):
    """Class extending the CircuitQuery class with methods for creation of templates of analysis tables
    in 600A circuits (with/without EE, RCBXH/V, RCD/O).

    """

    def create_report_analysis_template(self, timestamp_fgc: int, init_file_path: str, author='') -> pd.DataFrame:
        """ Method creating a report analysis template for 600A circuits with/without EE

        :param timestamp_fgc: timestamp of an FGC event
        :type timestamp_fgc: int
        :param init_file_path: path to an init file to read LHCSM-HWC notebooks version
        :type init_file_path: str
        :param author: NICE account name of the analysis author
        :type author: str
        :return: pre-filled pd.DataFrame with a template to be filled further with data from an analysis of
            a powering event in 600A circuits with/without EE
        """
        columns = Reference.read_quench_database_columns(circuit_type='600A', table_type='MP3')

        results_table = pd.DataFrame(columns=columns, index=[0])
        results_table['Circuit Name'] = self.circuit_name
        results_table['Circuit Family'] = self.circuit_name.split('.')[0]
        results_table['Period'] = Reference.get_mp3_period(timestamp_fgc)
        results_table['Date (FGC)'] = Time.to_string_short(timestamp_fgc).split(' ')[0]
        results_table['Time (FGC)'] = Time.to_string_short(timestamp_fgc).split(' ')[1]
        results_table['Analysis performed by'] = author
        results_table['lhcsmapi version'] = lhcsmapi.__version__
        results_table['lhcsm notebook version'] = lhcsmapi.parse_lhcsmhwc_version(init_file_path)

        return results_table

    def create_report_analysis_template_rcd(self, timestamp_fgc_rcd: int, timestamp_fgc_rco: int,
                                            init_file_path: str, circuit_names: List[str], author='') -> pd.DataFrame:
        """ Method creating a report analysis template for RCD/RCO 600A circuits

        :param timestamp_fgc_rcd: timestamp of an FGC event in RCD circuit
        :type timestamp_fgc_rcd: int
        :param timestamp_fgc_rco: timestamp of an FGC event in RCO circuit
        :type timestamp_fgc_rco: int
        :param init_file_path: path to an init file to read LHCSM-HWC notebooks version
        :type init_file_path: str
        :param circuit_names: list of RCD/RCO circuit names [RCD.xxx, RCO.xxx]
        :type: List[str]
        :param author: NICE account name of the analysis author
        :type author: str
        :return: pre-filled pd.DataFrame with a template to be filled further with data from analysis of
            a powering event in RCD/RCO 600A circuits
        """
        columns = Reference.read_quench_database_columns(circuit_type='600A_RCDO', table_type='MP3')

        results_table = pd.DataFrame(columns=columns, index=[0])
        results_table['Circuit Name'] = circuit_names[0].replace('D', '').replace('O', '')
        results_table['Circuit Family'] = 'RCD'

        timestamp_fgc = min(timestamp_fgc_rcd, timestamp_fgc_rco)
        results_table['Period'] = Reference.get_mp3_period(timestamp_fgc)
        results_table['Date (FGC)'] = Time.to_string_short(timestamp_fgc).split(' ')[0]
        results_table['Time (FGC)'] = Time.to_string_short(timestamp_fgc).split(' ')[1]
        results_table['Analysis performed by'] = author
        results_table['lhcsmapi version'] = lhcsmapi.__version__
        results_table['lhcsm notebook version'] = lhcsmapi.parse_lhcsmhwc_version(init_file_path)

        return results_table

    def create_report_analysis_template_rcbx(self, timestamp_fgc_rcbxh: int, timestamp_fgc_rcbxv: int,
                                             init_file_path: str, circuit_names: List[str], author='') -> pd.DataFrame:
        """ Method creating a report analysis template for RCBXH/RCBXV 600A circuits

        :param timestamp_fgc_rcbxh: timestamp of an FGC event in RCBXH circuit
        :type timestamp_fgc_rcbxh: int
        :param timestamp_fgc_rcbxv: timestamp of an FGC event in RCBXV circuit
        :type timestamp_fgc_rcbxv: int
        :param init_file_path: path to an init file to read LHCSM-HWC notebooks version
        :type init_file_path: str
        :param circuit_names: list of RCBXH/RCBXV circuit names [RCBXH.xxx, RCBXV.xxx]
        :type: List[str]
        :param author: NICE account name of the analysis author
        :type author: str
        :return: pre-filled pd.DataFrame with a template to be filled further with data from analysis
            of a powering event in RCBXH/RCBXV 600A circuits
        """
        columns = Reference.read_quench_database_columns(circuit_type='600A_RCBXHV', table_type='MP3')

        results_table = pd.DataFrame(columns=columns, index=[0])
        results_table['Circuit Name'] = circuit_names[0].replace('H', '').replace('V', '')
        results_table['Circuit Family'] = 'RCBX'

        timestamp_fgc = min(timestamp_fgc_rcbxh, timestamp_fgc_rcbxv)
        results_table['Period'] = Reference.get_mp3_period(timestamp_fgc)
        results_table['Date (FGC)'] = Time.to_string_short(timestamp_fgc).split(' ')[0]
        results_table['Time (FGC)'] = Time.to_string_short(timestamp_fgc).split(' ')[1]
        results_table['Analysis performed by'] = author
        results_table['lhcsmapi version'] = lhcsmapi.__version__
        results_table['lhcsm notebook version'] = lhcsmapi.parse_lhcsmhwc_version(init_file_path)

        return results_table

==> lhcsmapi-1.5.13.tar.gz: lhcsmapi-1.5.13/lhcsmapi/analysis/R600ACircuitQuery.py <==
from typing import List

import pandas as pd

import lhcsmapi
from lhcsmapi.Time import Time
from lhcsmapi.analysis.CircuitQuery import CircuitQuery, min_nan
from lhcsmapi.analysis.dfb.DfbQuery import DfbQuery
from lhcsmapi.analysis.ee.EeQuery import EeQuery
from lhcsmapi.analysis.pc.PcQuery import PcQuery
from lhcsmapi.analysis.pic.PicQuery import PicQuery
from lhcsmapi.analysis.qds.QdsQuery import QdsQuery
from lhcsmapi.reference.Reference import Reference


class R600ACircuitQuery(PicQuery, PcQuery, EeQuery, QdsQuery, DfbQuery, CircuitQuery):
    """Class extending the CircuitQuery class with methods for creation of templates of analysis tables
    in 600A circuits (with/without EE, RCBXH/V, RCD/O).

    """

    def create_report_analysis_template(self, timestamp_fgc: int, init_file_path: str, author='') -> pd.DataFrame:
        """ Method creating a report analysis template for 600A circuits with/without EE

        :param timestamp_fgc: timestamp of an FGC event
        :type timestamp_fgc: int
        :param init_file_path: path to an init file to read LHCSM-HWC notebooks version
        :type init_file_path: str
        :param author: NICE account name of the analysis author
        :type author: str
        :return: pre-filled pd.DataFrame with a template to be filled further with data from an analysis of
            a powering event in 600A circuits with/without EE
        """
        columns = Reference.read_quench_database_columns(circuit_type='600A', table_type='MP3')

        results_table = pd.DataFrame(columns=columns, index=[0])
        results_table['Circuit Name'] = self.circuit_name
        results_table['Circuit Family'] = self.circuit_name.split('.')[0]
        results_table['Period'] = Reference.get_mp3_period(timestamp_fgc)
        results_table['Date (FGC)'] = Time.to_string_short(timestamp_fgc).split(' ')[0]
        results_table['Time (FGC)'] = Time.to_string_short(timestamp_fgc).split(' ')[1]
        results_table['Analysis performed by'] = author
        results_table['lhcsmapi version'] = lhcsmapi.__version__
        results_table['lhcsm notebook version'] = lhcsmapi.parse_lhcsmhwc_version(init_file_path)

        return results_table

    def create_report_analysis_template_rcd(self, timestamp_fgc_rcd: int, timestamp_fgc_rco: int,
                                            init_file_path: str, circuit_names: List[str], author='') -> pd.DataFrame:
        """ Method creating a report analysis template for RCD/RCO 600A circuits

        :param timestamp_fgc_rcd: timestamp of an FGC event in RCD circuit
        :type timestamp_fgc_rcd: int
        :param timestamp_fgc_rco: timestamp of an FGC event in RCO circuit
        :type timestamp_fgc_rco: int
        :param init_file_path: path to an init file to read LHCSM-HWC notebooks version
        :type init_file_path: str
        :param circuit_names: list of RCD/RCO circuit names [RCD.xxx, RCO.xxx]
        :type: List[str]
        :param author: NICE account name of the analysis author
        :type author: str
        :return: pre-filled pd.DataFrame with a template to be filled further with data from analysis of
            a powering event in RCD/RCO 600A circuits
        """
        columns = Reference.read_quench_database_columns(circuit_type='600A_RCDO', table_type='MP3')

        results_table = pd.DataFrame(columns=columns, index=[0])
        # Assumes that circuit_names[0] is always RCD
        results_table['Circuit Name'] = circuit_names[0].replace('RCD', 'RCD-RCO')
        results_table['Circuit Family'] = 'RCD'

        timestamp_fgc = min_nan(timestamp_fgc_rcd, timestamp_fgc_rco)
        results_table['Period'] = Reference.get_mp3_period(timestamp_fgc)
        results_table['Date (FGC)'] = Time.to_string_short(timestamp_fgc).split(' ')[0]
        results_table['Time (FGC)'] = Time.to_string_short(timestamp_fgc).split(' ')[1]
        results_table['Analysis performed by'] = author
        results_table['lhcsmapi version'] = lhcsmapi.__version__
        results_table['lhcsm notebook version'] = lhcsmapi.parse_lhcsmhwc_version(init_file_path)

        return results_table

    def create_report_analysis_template_rcbx(self, timestamp_fgc_rcbxh: int, timestamp_fgc_rcbxv: int,
                                             init_file_path: str, circuit_names: List[str], author='') -> pd.DataFrame:
        """ Method creating a report analysis template for RCBXH/RCBXV 600A circuits

        :param timestamp_fgc_rcbxh: timestamp of an FGC event in RCBXH circuit
        :type timestamp_fgc_rcbxh: int
        :param timestamp_fgc_rcbxv: timestamp of an FGC event in RCBXV circuit
        :type timestamp_fgc_rcbxv: int
        :param init_file_path: path to an init file to read LHCSM-HWC notebooks version
        :type init_file_path: str
        :param circuit_names: list of RCBXH/RCBXV circuit names [RCBXH.xxx, RCBXV.xxx]
        :type: List[str]
        :param author: NICE account name of the analysis author
        :type author: str
        :return: pre-filled pd.DataFrame with a template to be filled further with data from analysis
            of a powering event in RCBXH/RCBXV 600A circuits
        """
        columns = Reference.read_quench_database_columns(circuit_type='600A_RCBXHV', table_type='MP3')

        results_table = pd.DataFrame(columns=columns, index=[0])
        results_table['Circuit Name'] = circuit_names[0].replace('H', '').replace('V', '')
        results_table['Circuit Family'] = 'RCBX'

        timestamp_fgc = min_nan(timestamp_fgc_rcbxh, timestamp_fgc_rcbxv)
        results_table['Period'] = Reference.get_mp3_period(timestamp_fgc)
        results_table['Date (FGC)'] = Time.to_string_short(timestamp_fgc).split(' ')[0]
        results_table['Time (FGC)'] = Time.to_string_short(timestamp_fgc).split(' ')[1]
        results_table['Analysis performed by'] = author
        results_table['lhcsmapi version'] = lhcsmapi.__version__
        results_table['lhcsm notebook version'] = lhcsmapi.parse_lhcsmhwc_version(init_file_path)

        return results_table
